@@ -165,7 +165,6 @@ else:
     #######################
     ### Привязка к pysi ###
     #######################
-    from exceptions import NotFound
     from config import cfg
     import wsgi
 
@@ -184,7 +183,7 @@ else:
                 func, kwargs = urls.find(rq.path + '/')
                 if func:
                     return wsgi.redirect(rq.path + '/')        
-            raise NotFound
+            wsgi.abort(404)
         return func(rq, **kwargs)
         
     def add_urls(*rules):
